@@ -10,8 +10,9 @@ describe 'mistral::wsgi::apache' do
         :bind_port                   => 8989,
         :group                       => 'mistral',
         :path                        => '/',
+        :priority                    => 10,
         :servername                  => facts[:fqdn],
-        :ssl                         => true,
+        :ssl                         => false,
         :threads                     => 1,
         :user                        => 'mistral',
         :workers                     => facts[:os_workers],
@@ -20,27 +21,33 @@ describe 'mistral::wsgi::apache' do
         :wsgi_script_dir             => platform_params[:wsgi_script_path],
         :wsgi_script_file            => 'app',
         :wsgi_script_source          => platform_params[:wsgi_script_source],
-        :access_log_file             => false,
-        :access_log_format           => false,
+        :headers                     => nil,
+        :request_headers             => nil,
+        :access_log_file             => nil,
+        :access_log_pipe             => nil,
+        :access_log_syslog           => nil,
+        :access_log_format           => nil,
+        :error_log_file              => nil,
+        :error_log_pipe              => nil,
+        :error_log_syslog            => nil,
         :custom_wsgi_process_options => {},
       )}
     end
 
-    context 'when overriding parameters using different ports' do
+    context 'when overriding parameters' do
       let :params do
         {
           :servername                  => 'dummy.host',
           :bind_host                   => '10.42.51.1',
           :port                        => 12345,
-          :ssl                         => false,
+          :ssl                         => true,
           :wsgi_process_display_name   => 'mistral',
           :workers                     => 37,
-          :access_log_file             => '/var/log/httpd/access_log',
-          :access_log_format           => 'some format',
-          :error_log_file              => '/var/log/httpd/error_log',
           :custom_wsgi_process_options => {
             'python_path' => '/my/python/path',
           },
+          :headers                     => ['set X-XSS-Protection "1; mode=block"'],
+          :request_headers             => ['set Content-Type "application/json"'],
           :vhost_custom_fragment       => 'Timeout 99',
         }
       end
@@ -52,7 +59,7 @@ describe 'mistral::wsgi::apache' do
         :group                       => 'mistral',
         :path                        => '/',
         :servername                  => 'dummy.host',
-        :ssl                         => false,
+        :ssl                         => true,
         :threads                     => 1,
         :user                        => 'mistral',
         :vhost_custom_fragment       => 'Timeout 99',
@@ -63,14 +70,77 @@ describe 'mistral::wsgi::apache' do
         :wsgi_script_dir             => platform_params[:wsgi_script_path],
         :wsgi_script_file            => 'app',
         :wsgi_script_source          => platform_params[:wsgi_script_source],
-        :access_log_file             => '/var/log/httpd/access_log',
-        :access_log_format           => 'some format',
-        :error_log_file              => '/var/log/httpd/error_log',
+        :headers                     => ['set X-XSS-Protection "1; mode=block"'],
+        :request_headers             => ['set Content-Type "application/json"'],
         :custom_wsgi_process_options => {
           'python_path' => '/my/python/path',
         },
       )}
     end
+
+    context 'with custom access logging' do
+      let :params do
+        {
+          :access_log_format => 'foo',
+          :access_log_syslog => 'syslog:local0',
+          :error_log_syslog  => 'syslog:local1',
+        }
+      end
+
+      it { should contain_openstacklib__wsgi__apache('mistral_wsgi').with(
+        :access_log_format => params[:access_log_format],
+        :access_log_syslog => params[:access_log_syslog],
+        :error_log_syslog  => params[:error_log_syslog],
+      )}
+    end
+
+    context 'with access_log_file' do
+      let :params do
+        {
+          :access_log_file => '/path/to/file',
+        }
+      end
+
+      it { should contain_openstacklib__wsgi__apache('mistral_wsgi').with(
+        :access_log_file => params[:access_log_file],
+      )}
+    end
+
+    context 'with access_log_pipe' do
+      let :params do
+        {
+          :access_log_pipe => 'pipe',
+        }
+      end
+
+      it { should contain_openstacklib__wsgi__apache('mistral_wsgi').with(
+        :access_log_pipe => params[:access_log_pipe],
+      )}
+    end
+
+    context 'with error_log_file' do
+      let :params do
+        {
+          :error_log_file => '/path/to/file',
+        }
+      end
+
+      it { should contain_openstacklib__wsgi__apache('mistral_wsgi').with(
+        :error_log_file => params[:error_log_file],
+      )}
+    end
+
+    context 'with error_log_pipe' do
+      let :params do
+        {
+          :error_log_pipe => 'pipe',
+        }
+      end
+
+      it { should contain_openstacklib__wsgi__apache('mistral_wsgi').with(
+        :error_log_pipe => params[:error_log_pipe],
+      )}
+    end
   end
 
   on_supported_os({
@@ -89,15 +159,11 @@ describe 'mistral::wsgi::apache' do
         case facts[:osfamily]
         when 'Debian'
           {
-            :httpd_service_name => 'apache2',
-            :httpd_ports_file   => '/etc/apache2/ports.conf',
             :wsgi_script_path   => '/usr/lib/cgi-bin/mistral',
             :wsgi_script_source => '/usr/bin/mistral-wsgi-api'
           }
         when 'RedHat'
           {
-            :httpd_service_name => 'httpd',
-            :httpd_ports_file   => '/etc/httpd/conf/ports.conf',
             :wsgi_script_path   => '/var/www/cgi-bin/mistral',
             :wsgi_script_source => '/usr/bin/mistral-wsgi-api'
           }
